
package com.reactlibrary;

import android.app.Activity;
import android.view.View;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.WritableMap;

import java.util.HashMap;
import java.util.Map;


import com.facebook.react.uimanager.IllegalViewOperationException;
import static com.facebook.react.bridge.UiThreadUtil.runOnUiThread;

public class RNReactNativeNavigationBarModule extends ReactContextBaseJavaModule {

  private final ReactApplicationContext reactContext;
  private static final int UI_FLAG_HIDE_NAV_BAR = View.SYSTEM_UI_FLAG_LAYOUT_STABLE
          | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
          | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION // hide nav bar
          | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY;

  public RNReactNativeNavigationBarModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
  }

  @Override
  public String getName() {
    return "RNReactNativeNavigationBar";
  }

  @Override
  public Map<String, Object> getConstants() {
      // Export any constants to be used in your native module
      // https://facebook.github.io/react-native/docs/native-modules-android.html#the-toast-module
      final Map<String, Object> constants = new HashMap<>();
      constants.put("EXAMPLE_CONSTANT", "example");

      return constants;
  }

  @ReactMethod
  public void Hide(Promise promise) {
    try {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                View decorView = getCurrentActivity().getWindow().getDecorView();
                decorView.setSystemUiVisibility(UI_FLAG_HIDE_NAV_BAR);
            }
        });
    } catch (IllegalViewOperationException e) {
        WritableMap map = Arguments.createMap();
        map.putBoolean("success", false);
        promise.reject("error", e);
    }

  }

  @ReactMethod
  public void Show(Promise promise) {
      try {
          runOnUiThread(new Runnable() {
              @Override
              public void run() {
                  View decorView = getCurrentActivity().getWindow().getDecorView();

                  int uiOptions = View.SYSTEM_UI_FLAG_VISIBLE;

                  decorView.setSystemUiVisibility(uiOptions);
              }
          });
      } catch (IllegalViewOperationException e) {
          WritableMap map = Arguments.createMap();
          map.putBoolean("success", false);
          promise.reject("error", e);
      }
  }
}
